@@ -10,7 +10,7 @@ use File::Spec;
 
 use base 'Exporter';
 our @EXPORT_OK = qw(withVCR);
-our $VERSION   = '0.2';
+our $VERSION   = '0.3';
 
 =head1 NAME
 
@@ -101,7 +101,10 @@ sub record {
 	};
 	
 	local $_ = $self;
-	$code->();
+	eval {
+		$code->();
+	};
+	my $e = $@;
 	
 	open(my $fh, '>', $self->{tape}) || die "Couldn't open $self->{tape}: $!\n";
 	
@@ -110,6 +113,8 @@ sub record {
 	print $fh "use HTTP::Request;\n";
 	print $fh Data::Dumper::Dumper($tape), "\n";
 	close($fh) || die "Couldn't close $self->{tape}: $!\n";
+
+	die $e if $e;
 }
 
 sub play {
@@ -193,7 +198,7 @@ a code ref.  For example:
 		my $req = $ua->post('http://oo.com/object');
 		isa_ok($req, 'HTTP::Response');
 		
-		if ($_->isRecording) {
+		if ($_->is_recording) {
 			sleep(5);
 		}
 		
